library(glmmTMB)
library(tidyverse)
library(ggpubr)
library(ggeffects)


library(sjPlot)
library(sjmisc)
library(sjlabelled)

dat1 <- readRDS('ROI_myc_staining_2Mar2023_unscaled.rds')
dat2 <- readRDS('ROI_myc_staining_2Mar2023_NPL.rds')

dat <- bind_rows(dat1 %>%
  select(tissue, color, `218.1032`) %>%
    rename(PA = `218.1032`) %>%
    mutate(run = 1),
  dat2 %>%
    select(tissue, color, `218.1034`) %>%
    rename(PA = `218.1034`) %>%
    mutate(run = 2,
           tissue = tissue + 4))

dat <- dat %>%
  mutate(Myc = factor(ifelse(.$color == "G", "High", "Low")))

thresholds <- dat %>%
  group_by(run, tissue) %>%
  summarise(th = median(PA)) %>%
  ungroup()

mask_pa <- numeric(nrow(dat))
for (i in thresholds$run) {
  for (j in thresholds$tissue) {
    mask_pa[which((dat$run == i) & (dat$tissue == j))] <- 
      dat$PA[which((dat$run == i) & (dat$tissue == j))] > thresholds %>%
      filter(run == i & tissue == j) %>%
      pull(th)
  }
}

dat <- dat %>%
  mutate(PA_binary = mask_pa)

prop_pa <- tibble(run = numeric(), tissue = numeric(),
                  Myc = character(), prop = numeric())
for (i in unique(dat$run)) {
  for (j in unique(dat %>% filter(run == i) %>% pull(tissue))) {
    prop_pa <- bind_rows(
      prop_pa,
      tibble(
        run = i,
        tissue = j,
        Myc = "High",
        prop = dat %>%
          filter(run == i & tissue == j) %>%
          filter(Myc == "High") %>%
          {
            sum(.$PA_binary) / nrow(.)
          }
      ),
      tibble(
        run = i,
        tissue = j,
        Myc = "Low",
        prop = dat %>%
          filter(run == i & tissue == j) %>%
          filter(Myc == "Low") %>%
          {
            sum(.$PA_binary) / nrow(.)
          }
      )
    )
  }
}

prop_pa <- prop_pa %>%
  mutate(run = as.factor(run),
         tissue = as.factor(tissue))

mdl <- glmmTMB(prop ~ Myc + (1|run) + (1|tissue), data=as.data.frame(prop_pa),
               family = beta_family())

ggplot(data = NULL, aes(y = resid(mdl, type = "pearson"),
                        x = fitted(mdl))) + geom_point()

prop_pa 

pred <- ggpredict(mdl, terms=c('Myc'))
p <- ggplot() +
  geom_point(aes(x=Myc, y=prop, color=tissue, shape=run), size=5, data=prop_pa) +
  geom_line(aes(x=Myc, y=prop, group=tissue, color=tissue), data=prop_pa) +
  scale_color_brewer(palette='Set1') +
  geom_point(aes(x = x, y = predicted), size=5, color='black', data=pred) +
  geom_errorbar(aes(x=x, ymin=conf.low, ymax=conf.high), color='black', data=pred, width=0.1, size=1) +
  labs(#title=paste0(mz_module[i], ' m/z'),
       x='Myc Level') +
  ylab("Proportion PA-high") +
  scale_x_discrete(labels = c("high", "low")) +
  theme_classic() +
  guides(color = guide_legend(title = "Sample"),
         shape = guide_legend(title = "Run"))
ggsave(filename = 'preds_PA_pdx_2023.pdf', plot = p, dpi = 300, width = 4, height = 4)


tab_model(mdl, file = 'summary_fit_PA_pdx.html')
